import { Callback, Context, SQSRecord } from 'aws-lambda';
import { IAPIGatewayHelper } from 'typescript-aws-apigateway-helper';
import { ICloudWatchHelper } from 'typescript-aws-cloudwatch-helper';
import { IDynamoHelper } from 'typescript-aws-dynamo-helper';
import { IKMSHelper } from 'typescript-aws-kms-helper';
import { ILambdaHelper } from 'typescript-aws-lambda-helper';
import { IS3Helper } from 'typescript-aws-s3-helper';
import { ISESHelper } from 'typescript-aws-ses-helper';
import { ISNSHelper } from 'typescript-aws-sns-helper';
import { ISQSHelper } from 'typescript-aws-sqs-helper';
import { ISSMHelper } from 'typescript-aws-ssm-helper';
import { ISTSHelper } from 'typescript-aws-sts-helper';
import { ILogger, LogLevel } from 'typescript-ilogger';
import { IHandler } from './interface';
import { LogHelper, ObjectOperations } from 'typescript-helper-functions';
/**
 * Handles an incoming lambda execution request
 */
export declare class Handler implements IHandler {
    private LogLevel;
    APIGatewayHelper: IAPIGatewayHelper;
    CloudWatchHelper: ICloudWatchHelper;
    DynamoHelper: IDynamoHelper;
    KMSHelper: IKMSHelper;
    LambdaHelper: ILambdaHelper;
    Logger: ILogger;
    S3Helper: IS3Helper;
    SESHelper: ISESHelper;
    SNSHelper: ISNSHelper;
    SQSHelper: ISQSHelper;
    SSMHelper: ISSMHelper;
    STSHelper: ISTSHelper;
    LogHelper: LogHelper;
    ObjectOperations: ObjectOperations;
    /**
     * Initialize a new instance of Handler
     * @param LogLevel {LogLevel} Log Level
     */
    constructor(LogLevel: LogLevel);
    /**
     * Execute a lambda
     * @param payload {T} Payload to use
     * @param context {Context} AWS Context
     * @param callback {Callback} AWS Callback
     * @param actionToExecute {function} Action to take
     */
    Execute<T>(payload: T, context: Context, callback: Callback<any>, actionToExecute: () => Promise<T>): Promise<void>;
    /**
     * Orchestrate a function
     * @param actionToExecute {function} Action to take
     */
    Orchestrate<T>(actionToExecute: () => Promise<T>): Promise<T>;
    /**
     * Orchestrate function to process records off SQS queue
     * @param records {SQSRecord[]} Records to process
     * @param queueUrl {string} Queue URL of record set
     * @param actionToExecute {function} Action to perform on each record
     */
    OrchestrateSQS(records: SQSRecord[], queueUrl: string, actionToExecute: () => Promise<void>): Promise<void>;
}
